#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wl-pprint-terminfo
version:              3.7.1.4
visibility:           public
id:                   wl-pprint-terminfo-3.7.1.4-KmjpkvJQv4DCsCi803IxKW
key:                  wl-pprint-terminfo-3.7.1.4-KmjpkvJQv4DCsCi803IxKW
license:              BSD-3-Clause
copyright:            Copyright (C) 2011 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/wl-pprint-terminfo/
synopsis:             A color pretty printer with terminfo support
description:          A color pretty printer with terminfo support
category:             Control, Monads, Text
abi:                  a60d7e7b0d3ba1270a6279504a975e62
exposed:              True
exposed-modules:      System.Console.Terminfo.PrettyPrint
hidden-modules:       System.Console.Terminfo.PrettyPrint.Curses
import-dirs:          /usr/lib/ghc-9.6.6/site-local/wl-pprint-terminfo-3.7.1.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/wl-pprint-terminfo-3.7.1.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/wl-pprint-terminfo-3.7.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wl-pprint-terminfo
hs-libraries:         HSwl-pprint-terminfo-3.7.1.4-KmjpkvJQv4DCsCi803IxKW
extra-libraries:      ncursesw
includes:             cursed.h
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7 terminfo-0.4.1.6
    text-2.0.2 transformers-0.6.1.0
    wl-pprint-extras-3.5.0.5-3q6OFVSkpoJtudYeWGCak

haddock-interfaces:
    /usr/share/doc/haskell-wl-pprint-terminfo/html/wl-pprint-terminfo.haddock

haddock-html:         /usr/share/doc/haskell-wl-pprint-terminfo/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

